![logo](https://raw.github.com/MrYsLab/pymata-express/master/documentation/images/pymata_express.png)
=====================================================================================================

### Pymata-express is a high performance, non-blocking, Python asyncio client for the Arduino Firmata Protocol.

### It supports the complete StandardFirmata protocol in addition to an enhanced version of StandardFirmata called FirmataExpress.

<h2><u>Major features</u></h2>

* **Python 3.7+ compatible.**

* **Fully documented [API.](https://mryslab.github.io/pymata-express/api/)**

* **[User's Guide](https://mryslab.github.io/pymata-express/), Including Examples.**

* **Implements 100% of the StandardFirmata Protocol (StandardFirmata 2.5.8).**

* **Advanced auto-detection of Arduino devices (when using FirmataExpress).**

* **[FirmataExpress](https://github.com/MrYsLab/FirmataExpress) (enhanced StandardFirmata sketch) adds support for:**
     * **HC-SR04 Ultrasonic Distance Sensors using a single pin.**
     * **Stepper Motors.**
     * **Piezo Tone Generation.**
     * **Baud rate of 115200**

This project was developed with [Pycharm](https://www.jetbrains.com/pycharm/) ![logo](https://github.com/MrYsLab/python_banyan/blob/master/images/icon_PyCharm.png)
